@@ -15,6 +15,7 @@ class FileDumper(DumperBase):
         super(FileDumper, self).__init__(options)
         self.force_format = options.get('force_format', True)
         self.forced_format = options.get('format', 'csv')
+        self.temporal_format_property = options.get('temporal_format_property', None)
         self.use_titles = options.get('use_titles', False)
 
     def process_datapackage(self, datapackage):
@@ -44,6 +45,17 @@ class FileDumper(DumperBase):
         return datapackage
 
     def handle_datapackage(self):
+
+        # Handle temporal_format_property
+        if self.temporal_format_property:
+            for resource in self.datapackage.descriptor['resources']:
+                for field in resource['schema']['fields']:
+                    if field.get('type') in ['datetime', 'date', 'time']:
+                        format = field.pop(self.temporal_format_property, None)
+                        if format:
+                            field['format'] = format
+            self.datapackage.commit()
+
         temp_file = tempfile.NamedTemporaryFile(mode="w+", delete=False, encoding='utf-8')
         indent = 2 if self.pretty_descriptor else None
         json.dump(self.datapackage.descriptor, temp_file, indent=indent, sort_keys=True, ensure_ascii=False)
@@ -66,18 +78,24 @@ class FileDumper(DumperBase):
             yield row
         writer.finalize_file()
 
+        # Get resource descriptor
+        resource_descriptor = resource.res.descriptor
+        for descriptor in self.datapackage.descriptor['resources']:
+            if descriptor['name'] == resource.res.descriptor['name']:
+                resource_descriptor = descriptor
+
         # File size:
         filesize = temp_file.tell()
         DumperBase.inc_attr(self.datapackage.descriptor, self.datapackage_bytes, filesize)
-        DumperBase.inc_attr(resource.res.descriptor, self.resource_bytes, filesize)
+        DumperBase.inc_attr(resource_descriptor, self.resource_bytes, filesize)
 
         # File Hash:
         if self.resource_hash:
             hasher = FileDumper.hash_handler(temp_file)
             # Update path with hash
             if self.add_filehash_to_path:
-                DumperBase.insert_hash_in_path(resource.res.descriptor, hasher.hexdigest())
-            DumperBase.set_attr(resource.res.descriptor, self.resource_hash, hasher.hexdigest())
+                DumperBase.insert_hash_in_path(resource_descriptor, hasher.hexdigest())
+            DumperBase.set_attr(resource_descriptor, self.resource_hash, hasher.hexdigest())
 
         # Finalise
         filename = temp_file.name
@@ -91,6 +109,7 @@ class FileDumper(DumperBase):
 
             temp_file = tempfile.NamedTemporaryFile(mode="w+", delete=False, newline='')
             writer_kwargs = {'use_titles': True} if self.use_titles else {}
+            writer_kwargs['temporal_format_property'] = self.temporal_format_property
             writer = self.file_formatters[resource.res.name](temp_file, schema, **writer_kwargs)
 
             return self.rows_processor(resource,
