@@ -63,7 +63,9 @@ class SQLDumper(DumperBase):
                                      "Please set your '%s' environment variable" % env_var)
 
             self.engine = create_engine(engine)
-            self.engine.connect()
+            # check connection
+            with self.engine.connect():
+                pass
         else:
             self.engine = engine
 
@@ -75,6 +77,8 @@ class SQLDumper(DumperBase):
 
         self.updated_column = updated_column
         self.updated_id_column = updated_id_column
+        self.batch_size = options.get('batch_size', 1000)
+        self.use_bloom_filter = options.get('use_bloom_filter', True)
 
     def normalize_for_engine(self, dialect, resource, schema_descriptor):
         actions = {}
@@ -129,7 +133,9 @@ class SQLDumper(DumperBase):
                            self.normalize_for_engine(self.engine.dialect.name,
                                                      resource, schema_descriptor),
                            keyed=True, as_generator=True,
-                           update_keys=update_keys
+                           update_keys=update_keys,
+                           buffer_size=self.batch_size,
+                           use_bloom_filter=self.use_bloom_filter,
                        ))
 
     def get_output_row(self, written):
